@@ -1,9 +1,9 @@
 package App::grep::url;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-10'; # DATE
+our $DATE = '2021-07-11'; # DATE
 our $DIST = 'App-grep-url'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -342,7 +342,13 @@ App::grep::url - Print lines having URL(s) (optionally of certain criteria) in t
 
 =head1 VERSION
 
-This document describes version 0.002 of App::grep::url (from Perl distribution App-grep-url), released on 2021-07-10.
+This document describes version 0.003 of App::grep::url (from Perl distribution App-grep-url), released on 2021-07-11.
+
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-dell-xps13)
+
+perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
 
 =head1 FUNCTIONS
 
